@@ -1,24 +1,9 @@
 /*
- * This file is part of the syndication library
- *
- * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
- *
- * This library is free software you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the syndication library
+    SPDX-FileCopyrightText: 2006 Frank Osterfeld <osterfeld@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "itematomimpl.h"
 #include "categoryatomimpl.h"
@@ -45,8 +30,8 @@ using Syndication::Atom::Person;
 
 namespace Syndication
 {
-
-ItemAtomImpl::ItemAtomImpl(const Syndication::Atom::Entry &entry) : m_entry(entry)
+ItemAtomImpl::ItemAtomImpl(const Syndication::Atom::Entry &entry)
+    : m_entry(entry)
 {
 }
 
@@ -57,18 +42,13 @@ QString ItemAtomImpl::title() const
 
 QString ItemAtomImpl::link() const
 {
-    QList<Syndication::Atom::Link> links = m_entry.links();
-    QList<Syndication::Atom::Link>::ConstIterator it = links.constBegin();
-    QList<Syndication::Atom::Link>::ConstIterator end = links.constEnd();
+    const QList<Syndication::Atom::Link> links = m_entry.links();
 
     // return first link where rel="alternate"
-    for (; it != end; ++it) {
-        if ((*it).rel() == QLatin1String("alternate")) {
-            return (*it).href();
-        }
-    }
-
-    return QString();
+    auto it = std::find_if(links.cbegin(), links.cend(), [](const Syndication::Atom::Link &link) {
+        return link.rel() == QLatin1String("alternate");
+    });
+    return it != links.cend() ? it->href() : QString{};
 }
 
 QString ItemAtomImpl::description() const
@@ -88,26 +68,14 @@ QString ItemAtomImpl::content() const
 
 QList<PersonPtr> ItemAtomImpl::authors() const
 {
-    QList<Syndication::Atom::Person> atomps = m_entry.authors();
-    QList<Syndication::Atom::Person> contributorAtoms = m_entry.contributors();
-    QList<Syndication::Atom::Person>::ConstIterator it = atomps.constBegin();
-    QList<Syndication::Atom::Person>::ConstIterator end = atomps.constEnd();
+    const QList<Syndication::Atom::Person> people = m_entry.authors() + m_entry.contributors();
 
     QList<PersonPtr> list;
-    list.reserve(atomps.count() + contributorAtoms.count());
+    list.reserve(people.size());
 
-    for (; it != end; ++it) {
-        PersonImplPtr ptr(new PersonImpl((*it).name(), (*it).uri(), (*it).email()));
-        list.append(ptr);
-    }
-
-    it = contributorAtoms.constBegin();
-    end = contributorAtoms.constEnd();
-
-    for (; it != end; ++it) {
-        PersonImplPtr ptr(new PersonImpl((*it).name(), (*it).uri(), (*it).email()));
-        list.append(ptr);
-    }
+    std::transform(people.cbegin(), people.cend(), std::back_inserter(list), [](const Syndication::Atom::Person &person) {
+        return PersonImplPtr(new PersonImpl(person.name(), person.uri(), person.email()));
+    });
 
     return list;
 }
@@ -139,7 +107,7 @@ QString ItemAtomImpl::language() const
 
 QString ItemAtomImpl::id() const
 {
-    QString id = m_entry.id();
+    const QString id = m_entry.id();
     if (!id.isEmpty()) {
         return id;
     }
@@ -151,14 +119,11 @@ QList<Syndication::EnclosurePtr> ItemAtomImpl::enclosures() const
 {
     QList<Syndication::EnclosurePtr> list;
 
-    QList<Syndication::Atom::Link> links = m_entry.links();
-    QList<Syndication::Atom::Link>::ConstIterator it = links.constBegin();
-    QList<Syndication::Atom::Link>::ConstIterator end = links.constEnd();
-
-    for (; it != end; ++it) {
-        if ((*it).rel() == QLatin1String("enclosure")) {
-            list.append(EnclosureAtomImplPtr(new EnclosureAtomImpl(*it)));
+    const QList<Syndication::Atom::Link> links = m_entry.links();
 
+    for (const auto &link : links) {
+        if (link.rel() == QLatin1String("enclosure")) {
+            list.append(EnclosureAtomImplPtr(new EnclosureAtomImpl(link)));
         }
     }
 
@@ -167,17 +132,14 @@ QList<Syndication::EnclosurePtr> ItemAtomImpl::enclosures() const
 
 QList<Syndication::CategoryPtr> ItemAtomImpl::categories() const
 {
-    QList<Syndication::CategoryPtr> list;
+    const QList<Syndication::Atom::Category> cats = m_entry.categories();
 
-    QList<Syndication::Atom::Category> cats = m_entry.categories();
-    QList<Syndication::Atom::Category>::ConstIterator it = cats.constBegin();
-    QList<Syndication::Atom::Category>::ConstIterator end = cats.constEnd();
+    QList<Syndication::CategoryPtr> list;
     list.reserve(cats.count());
 
-    for (; it != end; ++it) {
-        CategoryAtomImplPtr impl(new CategoryAtomImpl(*it));
-        list.append(impl);
-    }
+    std::transform(cats.cbegin(), cats.cend(), std::back_inserter(list), [](const Syndication::Atom::Category &c) {
+        return CategoryAtomImplPtr(new CategoryAtomImpl(c));
+    });
 
     return list;
 }
